from __future__ import annotations
from win32more.winrt.prelude import *
import win32more.Microsoft.Windows.AppNotifications
import win32more.Microsoft.Windows.AppNotifications.Builder
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
class AppNotificationAudioLooping(Enum, Int32):
    None_ = 0
    Loop = 1
class AppNotificationBuilder(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder
    _classid_ = 'Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_mixinmethod
    def AddArgument(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder, key: WinRT_String, value: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_mixinmethod
    def SetTimeStamp(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder, value: win32more.Windows.Foundation.DateTime) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_mixinmethod
    def SetDuration(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder, duration: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationDuration) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_mixinmethod
    def SetScenario(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder, value: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationScenario) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_mixinmethod
    def AddText(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder, text: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_mixinmethod
    def AddText2(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder, text: WinRT_String, properties: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationTextProperties) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_mixinmethod
    def SetAttributionText(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder, text: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_mixinmethod
    def SetAttributionText2(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder, text: WinRT_String, language: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_mixinmethod
    def SetInlineImage(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder, imageUri: win32more.Windows.Foundation.Uri) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_mixinmethod
    def SetInlineImage2(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder, imageUri: win32more.Windows.Foundation.Uri, imageCrop: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationImageCrop) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_mixinmethod
    def SetInlineImage3(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder, imageUri: win32more.Windows.Foundation.Uri, imagecrop: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationImageCrop, alternateText: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_mixinmethod
    def SetAppLogoOverride(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder, imageUri: win32more.Windows.Foundation.Uri) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_mixinmethod
    def SetAppLogoOverride2(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder, imageUri: win32more.Windows.Foundation.Uri, imageCrop: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationImageCrop) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_mixinmethod
    def SetAppLogoOverride3(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder, imageUri: win32more.Windows.Foundation.Uri, imageCrop: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationImageCrop, alternateText: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_mixinmethod
    def SetHeroImage(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder, imageUri: win32more.Windows.Foundation.Uri) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_mixinmethod
    def SetHeroImage2(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder, imageUri: win32more.Windows.Foundation.Uri, alternateText: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_mixinmethod
    def SetAudioUri(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder, audioUri: win32more.Windows.Foundation.Uri) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_mixinmethod
    def SetAudioUri2(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder, audioUri: win32more.Windows.Foundation.Uri, loop: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationAudioLooping) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_mixinmethod
    def SetAudioEvent(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder, appNotificationSoundEvent: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationSoundEvent) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_mixinmethod
    def SetAudioEvent2(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder, appNotificationSoundEvent: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationSoundEvent, loop: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationAudioLooping) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_mixinmethod
    def MuteAudio(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_mixinmethod
    def AddTextBox(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder, id: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_mixinmethod
    def AddTextBox2(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder, id: WinRT_String, placeHolderText: WinRT_String, title: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_mixinmethod
    def AddButton(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder, value: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButton) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_mixinmethod
    def AddComboBox(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder, value: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationComboBox) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_mixinmethod
    def AddProgressBar(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder, value: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_mixinmethod
    def BuildNotification(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder) -> win32more.Microsoft.Windows.AppNotifications.AppNotification: ...
    @winrt_mixinmethod
    def SetTag(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder, value: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_mixinmethod
    def SetGroup(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder, group: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_classmethod
    def IsUrgentScenarioSupported(cls: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilderStatics) -> Boolean: ...
AppNotificationBuilderContract: UInt32 = 131072
class AppNotificationButton(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButton
    _classid_ = 'Microsoft.Windows.AppNotifications.Builder.AppNotificationButton'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButton.CreateInstance(*args))
        elif len(args) == 1:
            super().__init__(move=win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButton.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_overload
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButton: ...
    @CreateInstance.register
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButtonFactory, content: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButton: ...
    @winrt_mixinmethod
    def get_Content(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButton) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Content(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButton, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Arguments(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButton) -> win32more.Windows.Foundation.Collections.IMap[WinRT_String, WinRT_String]: ...
    @winrt_mixinmethod
    def put_Arguments(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButton, value: win32more.Windows.Foundation.Collections.IMap[WinRT_String, WinRT_String]) -> Void: ...
    @winrt_mixinmethod
    def get_Icon(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButton) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def put_Icon(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButton, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_mixinmethod
    def get_ToolTip(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButton) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_ToolTip(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButton, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_ContextMenuPlacement(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButton) -> Boolean: ...
    @winrt_mixinmethod
    def put_ContextMenuPlacement(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButton, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_ButtonStyle(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButton) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButtonStyle: ...
    @winrt_mixinmethod
    def put_ButtonStyle(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButton, value: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButtonStyle) -> Void: ...
    @winrt_mixinmethod
    def get_InputId(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButton) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_InputId(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButton, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_InvokeUri(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButton) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def put_InvokeUri(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButton, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_mixinmethod
    def get_TargetAppId(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButton) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_TargetAppId(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButton, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def AddArgument(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButton, key: WinRT_String, value: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButton: ...
    @winrt_mixinmethod
    def SetIcon(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButton, value: win32more.Windows.Foundation.Uri) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButton: ...
    @winrt_mixinmethod
    def SetToolTip(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButton, value: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButton: ...
    @winrt_mixinmethod
    def SetContextMenuPlacement(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButton) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButton: ...
    @winrt_mixinmethod
    def SetButtonStyle(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButton, value: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButtonStyle) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButton: ...
    @winrt_mixinmethod
    def SetInputId(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButton, value: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButton: ...
    @winrt_mixinmethod
    def SetInvokeUri(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButton, protocolUri: win32more.Windows.Foundation.Uri) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButton: ...
    @winrt_mixinmethod
    def SetInvokeUri2(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButton, protocolUri: win32more.Windows.Foundation.Uri, targetAppId: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButton: ...
    @winrt_classmethod
    def IsToolTipSupported(cls: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButtonStatics) -> Boolean: ...
    @winrt_classmethod
    def IsButtonStyleSupported(cls: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationButtonStatics) -> Boolean: ...
    Arguments = property(get_Arguments, put_Arguments)
    ButtonStyle = property(get_ButtonStyle, put_ButtonStyle)
    Content = property(get_Content, put_Content)
    ContextMenuPlacement = property(get_ContextMenuPlacement, put_ContextMenuPlacement)
    Icon = property(get_Icon, put_Icon)
    InputId = property(get_InputId, put_InputId)
    InvokeUri = property(get_InvokeUri, put_InvokeUri)
    TargetAppId = property(get_TargetAppId, put_TargetAppId)
    ToolTip = property(get_ToolTip, put_ToolTip)
class AppNotificationButtonStyle(Enum, Int32):
    Default = 0
    Success = 1
    Critical = 2
class AppNotificationComboBox(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationComboBox
    _classid_ = 'Microsoft.Windows.AppNotifications.Builder.AppNotificationComboBox'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 1:
            super().__init__(move=win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationComboBox.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationComboBoxFactory, id: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationComboBox: ...
    @winrt_mixinmethod
    def get_Items(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationComboBox) -> win32more.Windows.Foundation.Collections.IMap[WinRT_String, WinRT_String]: ...
    @winrt_mixinmethod
    def put_Items(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationComboBox, value: win32more.Windows.Foundation.Collections.IMap[WinRT_String, WinRT_String]) -> Void: ...
    @winrt_mixinmethod
    def get_Title(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationComboBox) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Title(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationComboBox, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_SelectedItem(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationComboBox) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_SelectedItem(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationComboBox, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def AddItem(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationComboBox, id: WinRT_String, content: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationComboBox: ...
    @winrt_mixinmethod
    def SetTitle(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationComboBox, value: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationComboBox: ...
    @winrt_mixinmethod
    def SetSelectedItem(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationComboBox, id: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationComboBox: ...
    Items = property(get_Items, put_Items)
    SelectedItem = property(get_SelectedItem, put_SelectedItem)
    Title = property(get_Title, put_Title)
class AppNotificationDuration(Enum, Int32):
    Default = 0
    Long = 1
class AppNotificationImageCrop(Enum, Int32):
    Default = 0
    Circle = 1
class AppNotificationProgressBar(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationProgressBar
    _classid_ = 'Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar: ...
    @winrt_mixinmethod
    def get_Title(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationProgressBar) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Title(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationProgressBar, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Status(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationProgressBar) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Status(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationProgressBar, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationProgressBar) -> Double: ...
    @winrt_mixinmethod
    def put_Value(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationProgressBar, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_ValueStringOverride(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationProgressBar) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_ValueStringOverride(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationProgressBar, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def SetTitle(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationProgressBar, value: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar: ...
    @winrt_mixinmethod
    def BindTitle(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationProgressBar) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar: ...
    @winrt_mixinmethod
    def SetStatus(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationProgressBar, value: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar: ...
    @winrt_mixinmethod
    def BindStatus(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationProgressBar) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar: ...
    @winrt_mixinmethod
    def SetValue(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationProgressBar, value: Double) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar: ...
    @winrt_mixinmethod
    def BindValue(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationProgressBar) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar: ...
    @winrt_mixinmethod
    def SetValueStringOverride(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationProgressBar, value: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar: ...
    @winrt_mixinmethod
    def BindValueStringOverride(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationProgressBar) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar: ...
    Status = property(get_Status, put_Status)
    Title = property(get_Title, put_Title)
    Value = property(get_Value, put_Value)
    ValueStringOverride = property(get_ValueStringOverride, put_ValueStringOverride)
class AppNotificationScenario(Enum, Int32):
    Default = 0
    Reminder = 1
    Alarm = 2
    IncomingCall = 3
    Urgent = 4
class AppNotificationSoundEvent(Enum, Int32):
    Default = 0
    IM = 1
    Mail = 2
    Reminder = 3
    SMS = 4
    Alarm = 5
    Alarm2 = 6
    Alarm3 = 7
    Alarm4 = 8
    Alarm5 = 9
    Alarm6 = 10
    Alarm7 = 11
    Alarm8 = 12
    Alarm9 = 13
    Alarm10 = 14
    Call = 15
    Call2 = 16
    Call3 = 17
    Call4 = 18
    Call5 = 19
    Call6 = 20
    Call7 = 21
    Call8 = 22
    Call9 = 23
    Call10 = 24
class AppNotificationTextProperties(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationTextProperties
    _classid_ = 'Microsoft.Windows.AppNotifications.Builder.AppNotificationTextProperties'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationTextProperties.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationTextProperties: ...
    @winrt_mixinmethod
    def get_Language(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationTextProperties) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Language(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationTextProperties, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_IncomingCallAlignment(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationTextProperties) -> Boolean: ...
    @winrt_mixinmethod
    def put_IncomingCallAlignment(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationTextProperties, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_MaxLines(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationTextProperties) -> Int32: ...
    @winrt_mixinmethod
    def put_MaxLines(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationTextProperties, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def SetLanguage(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationTextProperties, value: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationTextProperties: ...
    @winrt_mixinmethod
    def SetIncomingCallAlignment(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationTextProperties) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationTextProperties: ...
    @winrt_mixinmethod
    def SetMaxLines(self: win32more.Microsoft.Windows.AppNotifications.Builder.IAppNotificationTextProperties, value: Int32) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationTextProperties: ...
    IncomingCallAlignment = property(get_IncomingCallAlignment, put_IncomingCallAlignment)
    Language = property(get_Language, put_Language)
    MaxLines = property(get_MaxLines, put_MaxLines)
class IAppNotificationBuilder(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilder'
    _iid_ = Guid('{e801d31f-ce03-505c-adec-8a02724ec9de}')
    @winrt_commethod(6)
    def AddArgument(self, key: WinRT_String, value: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_commethod(7)
    def SetTimeStamp(self, value: win32more.Windows.Foundation.DateTime) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_commethod(8)
    def SetDuration(self, duration: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationDuration) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_commethod(9)
    def SetScenario(self, value: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationScenario) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_commethod(10)
    def AddText(self, text: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_commethod(11)
    def AddText2(self, text: WinRT_String, properties: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationTextProperties) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_commethod(12)
    def SetAttributionText(self, text: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_commethod(13)
    def SetAttributionText2(self, text: WinRT_String, language: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_commethod(14)
    def SetInlineImage(self, imageUri: win32more.Windows.Foundation.Uri) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_commethod(15)
    def SetInlineImage2(self, imageUri: win32more.Windows.Foundation.Uri, imageCrop: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationImageCrop) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_commethod(16)
    def SetInlineImage3(self, imageUri: win32more.Windows.Foundation.Uri, imagecrop: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationImageCrop, alternateText: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_commethod(17)
    def SetAppLogoOverride(self, imageUri: win32more.Windows.Foundation.Uri) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_commethod(18)
    def SetAppLogoOverride2(self, imageUri: win32more.Windows.Foundation.Uri, imageCrop: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationImageCrop) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_commethod(19)
    def SetAppLogoOverride3(self, imageUri: win32more.Windows.Foundation.Uri, imageCrop: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationImageCrop, alternateText: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_commethod(20)
    def SetHeroImage(self, imageUri: win32more.Windows.Foundation.Uri) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_commethod(21)
    def SetHeroImage2(self, imageUri: win32more.Windows.Foundation.Uri, alternateText: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_commethod(22)
    def SetAudioUri(self, audioUri: win32more.Windows.Foundation.Uri) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_commethod(23)
    def SetAudioUri2(self, audioUri: win32more.Windows.Foundation.Uri, loop: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationAudioLooping) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_commethod(24)
    def SetAudioEvent(self, appNotificationSoundEvent: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationSoundEvent) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_commethod(25)
    def SetAudioEvent2(self, appNotificationSoundEvent: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationSoundEvent, loop: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationAudioLooping) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_commethod(26)
    def MuteAudio(self) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_commethod(27)
    def AddTextBox(self, id: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_commethod(28)
    def AddTextBox2(self, id: WinRT_String, placeHolderText: WinRT_String, title: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_commethod(29)
    def AddButton(self, value: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButton) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_commethod(30)
    def AddComboBox(self, value: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationComboBox) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_commethod(31)
    def AddProgressBar(self, value: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_commethod(32)
    def BuildNotification(self) -> win32more.Microsoft.Windows.AppNotifications.AppNotification: ...
    @winrt_commethod(33)
    def SetTag(self, value: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
    @winrt_commethod(34)
    def SetGroup(self, group: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder: ...
class IAppNotificationBuilderStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AppNotifications.Builder.IAppNotificationBuilderStatics'
    _iid_ = Guid('{c7042d2a-d319-520e-a314-50081c8888cc}')
    @winrt_commethod(6)
    def IsUrgentScenarioSupported(self) -> Boolean: ...
class IAppNotificationButton(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AppNotifications.Builder.IAppNotificationButton'
    _iid_ = Guid('{a7c03031-5634-5098-aec9-47ecb60c3499}')
    @winrt_commethod(6)
    def get_Content(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_Content(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def get_Arguments(self) -> win32more.Windows.Foundation.Collections.IMap[WinRT_String, WinRT_String]: ...
    @winrt_commethod(9)
    def put_Arguments(self, value: win32more.Windows.Foundation.Collections.IMap[WinRT_String, WinRT_String]) -> Void: ...
    @winrt_commethod(10)
    def get_Icon(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(11)
    def put_Icon(self, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_commethod(12)
    def get_ToolTip(self) -> WinRT_String: ...
    @winrt_commethod(13)
    def put_ToolTip(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(14)
    def get_ContextMenuPlacement(self) -> Boolean: ...
    @winrt_commethod(15)
    def put_ContextMenuPlacement(self, value: Boolean) -> Void: ...
    @winrt_commethod(16)
    def get_ButtonStyle(self) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButtonStyle: ...
    @winrt_commethod(17)
    def put_ButtonStyle(self, value: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButtonStyle) -> Void: ...
    @winrt_commethod(18)
    def get_InputId(self) -> WinRT_String: ...
    @winrt_commethod(19)
    def put_InputId(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(20)
    def get_InvokeUri(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(21)
    def put_InvokeUri(self, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_commethod(22)
    def get_TargetAppId(self) -> WinRT_String: ...
    @winrt_commethod(23)
    def put_TargetAppId(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(24)
    def AddArgument(self, key: WinRT_String, value: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButton: ...
    @winrt_commethod(25)
    def SetIcon(self, value: win32more.Windows.Foundation.Uri) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButton: ...
    @winrt_commethod(26)
    def SetToolTip(self, value: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButton: ...
    @winrt_commethod(27)
    def SetContextMenuPlacement(self) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButton: ...
    @winrt_commethod(28)
    def SetButtonStyle(self, value: win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButtonStyle) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButton: ...
    @winrt_commethod(29)
    def SetInputId(self, value: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButton: ...
    @winrt_commethod(30)
    def SetInvokeUri(self, protocolUri: win32more.Windows.Foundation.Uri) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButton: ...
    @winrt_commethod(31)
    def SetInvokeUri2(self, protocolUri: win32more.Windows.Foundation.Uri, targetAppId: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButton: ...
    Arguments = property(get_Arguments, put_Arguments)
    ButtonStyle = property(get_ButtonStyle, put_ButtonStyle)
    Content = property(get_Content, put_Content)
    ContextMenuPlacement = property(get_ContextMenuPlacement, put_ContextMenuPlacement)
    Icon = property(get_Icon, put_Icon)
    InputId = property(get_InputId, put_InputId)
    InvokeUri = property(get_InvokeUri, put_InvokeUri)
    TargetAppId = property(get_TargetAppId, put_TargetAppId)
    ToolTip = property(get_ToolTip, put_ToolTip)
class IAppNotificationButtonFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AppNotifications.Builder.IAppNotificationButtonFactory'
    _iid_ = Guid('{4f109286-0a6d-5a5e-9e8f-9fe31669fbb8}')
    @winrt_commethod(6)
    def CreateInstance(self, content: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationButton: ...
class IAppNotificationButtonStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AppNotifications.Builder.IAppNotificationButtonStatics'
    _iid_ = Guid('{fead7c18-4144-59a4-9611-86b7e8191853}')
    @winrt_commethod(6)
    def IsToolTipSupported(self) -> Boolean: ...
    @winrt_commethod(7)
    def IsButtonStyleSupported(self) -> Boolean: ...
class IAppNotificationComboBox(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AppNotifications.Builder.IAppNotificationComboBox'
    _iid_ = Guid('{4547c9e2-4815-538c-be26-040ce17f8b62}')
    @winrt_commethod(6)
    def get_Items(self) -> win32more.Windows.Foundation.Collections.IMap[WinRT_String, WinRT_String]: ...
    @winrt_commethod(7)
    def put_Items(self, value: win32more.Windows.Foundation.Collections.IMap[WinRT_String, WinRT_String]) -> Void: ...
    @winrt_commethod(8)
    def get_Title(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def put_Title(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(10)
    def get_SelectedItem(self) -> WinRT_String: ...
    @winrt_commethod(11)
    def put_SelectedItem(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(12)
    def AddItem(self, id: WinRT_String, content: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationComboBox: ...
    @winrt_commethod(13)
    def SetTitle(self, value: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationComboBox: ...
    @winrt_commethod(14)
    def SetSelectedItem(self, id: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationComboBox: ...
    Items = property(get_Items, put_Items)
    SelectedItem = property(get_SelectedItem, put_SelectedItem)
    Title = property(get_Title, put_Title)
class IAppNotificationComboBoxFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AppNotifications.Builder.IAppNotificationComboBoxFactory'
    _iid_ = Guid('{1b31b5b0-9d86-59ed-8629-a79498ab5d4b}')
    @winrt_commethod(6)
    def CreateInstance(self, id: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationComboBox: ...
class IAppNotificationProgressBar(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AppNotifications.Builder.IAppNotificationProgressBar'
    _iid_ = Guid('{fced62f2-2074-5641-8630-87a14315ac86}')
    @winrt_commethod(6)
    def get_Title(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_Title(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def get_Status(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def put_Status(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(10)
    def get_Value(self) -> Double: ...
    @winrt_commethod(11)
    def put_Value(self, value: Double) -> Void: ...
    @winrt_commethod(12)
    def get_ValueStringOverride(self) -> WinRT_String: ...
    @winrt_commethod(13)
    def put_ValueStringOverride(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(14)
    def SetTitle(self, value: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar: ...
    @winrt_commethod(15)
    def BindTitle(self) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar: ...
    @winrt_commethod(16)
    def SetStatus(self, value: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar: ...
    @winrt_commethod(17)
    def BindStatus(self) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar: ...
    @winrt_commethod(18)
    def SetValue(self, value: Double) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar: ...
    @winrt_commethod(19)
    def BindValue(self) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar: ...
    @winrt_commethod(20)
    def SetValueStringOverride(self, value: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar: ...
    @winrt_commethod(21)
    def BindValueStringOverride(self) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar: ...
    Status = property(get_Status, put_Status)
    Title = property(get_Title, put_Title)
    Value = property(get_Value, put_Value)
    ValueStringOverride = property(get_ValueStringOverride, put_ValueStringOverride)
class IAppNotificationTextProperties(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AppNotifications.Builder.IAppNotificationTextProperties'
    _iid_ = Guid('{23a30d0b-5258-5853-932e-9521a3642afb}')
    @winrt_commethod(6)
    def get_Language(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_Language(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def get_IncomingCallAlignment(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_IncomingCallAlignment(self, value: Boolean) -> Void: ...
    @winrt_commethod(10)
    def get_MaxLines(self) -> Int32: ...
    @winrt_commethod(11)
    def put_MaxLines(self, value: Int32) -> Void: ...
    @winrt_commethod(12)
    def SetLanguage(self, value: WinRT_String) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationTextProperties: ...
    @winrt_commethod(13)
    def SetIncomingCallAlignment(self) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationTextProperties: ...
    @winrt_commethod(14)
    def SetMaxLines(self, value: Int32) -> win32more.Microsoft.Windows.AppNotifications.Builder.AppNotificationTextProperties: ...
    IncomingCallAlignment = property(get_IncomingCallAlignment, put_IncomingCallAlignment)
    Language = property(get_Language, put_Language)
    MaxLines = property(get_MaxLines, put_MaxLines)


make_ready(__name__)



from __future__ import annotations
from win32more.winrt.prelude import *
import win32more.Microsoft.UI.Composition
import win32more.Microsoft.UI.Xaml.Controls
import win32more.Microsoft.UI.Xaml.Controls.AnimatedVisuals
import win32more.Windows.Foundation.Collections
import win32more.Windows.UI
class AnimatedAcceptVisualSource(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualSource
    _classid_ = 'Microsoft.UI.Xaml.Controls.AnimatedVisuals.AnimatedAcceptVisualSource'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.AnimatedVisuals.AnimatedAcceptVisualSource.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.AnimatedVisuals.AnimatedAcceptVisualSource: ...
    @winrt_mixinmethod
    def TryCreateAnimatedVisual(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualSource, compositor: win32more.Microsoft.UI.Composition.Compositor, diagnostics: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisual: ...
    @winrt_mixinmethod
    def get_Markers(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualSource2) -> win32more.Windows.Foundation.Collections.IMapView[WinRT_String, Double]: ...
    @winrt_mixinmethod
    def SetColorProperty(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualSource2, propertyName: WinRT_String, value: win32more.Windows.UI.Color) -> Void: ...
    Markers = property(get_Markers, None)
class AnimatedBackVisualSource(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualSource
    _classid_ = 'Microsoft.UI.Xaml.Controls.AnimatedVisuals.AnimatedBackVisualSource'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.AnimatedVisuals.AnimatedBackVisualSource.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.AnimatedVisuals.AnimatedBackVisualSource: ...
    @winrt_mixinmethod
    def TryCreateAnimatedVisual(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualSource, compositor: win32more.Microsoft.UI.Composition.Compositor, diagnostics: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisual: ...
    @winrt_mixinmethod
    def get_Markers(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualSource2) -> win32more.Windows.Foundation.Collections.IMapView[WinRT_String, Double]: ...
    @winrt_mixinmethod
    def SetColorProperty(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualSource2, propertyName: WinRT_String, value: win32more.Windows.UI.Color) -> Void: ...
    Markers = property(get_Markers, None)
class AnimatedChevronDownSmallVisualSource(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualSource
    _classid_ = 'Microsoft.UI.Xaml.Controls.AnimatedVisuals.AnimatedChevronDownSmallVisualSource'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.AnimatedVisuals.AnimatedChevronDownSmallVisualSource.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.AnimatedVisuals.AnimatedChevronDownSmallVisualSource: ...
    @winrt_mixinmethod
    def TryCreateAnimatedVisual(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualSource, compositor: win32more.Microsoft.UI.Composition.Compositor, diagnostics: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisual: ...
    @winrt_mixinmethod
    def get_Markers(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualSource2) -> win32more.Windows.Foundation.Collections.IMapView[WinRT_String, Double]: ...
    @winrt_mixinmethod
    def SetColorProperty(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualSource2, propertyName: WinRT_String, value: win32more.Windows.UI.Color) -> Void: ...
    Markers = property(get_Markers, None)
class AnimatedChevronRightDownSmallVisualSource(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualSource
    _classid_ = 'Microsoft.UI.Xaml.Controls.AnimatedVisuals.AnimatedChevronRightDownSmallVisualSource'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.AnimatedVisuals.AnimatedChevronRightDownSmallVisualSource.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.AnimatedVisuals.AnimatedChevronRightDownSmallVisualSource: ...
    @winrt_mixinmethod
    def TryCreateAnimatedVisual(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualSource, compositor: win32more.Microsoft.UI.Composition.Compositor, diagnostics: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisual: ...
    @winrt_mixinmethod
    def get_Markers(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualSource2) -> win32more.Windows.Foundation.Collections.IMapView[WinRT_String, Double]: ...
    @winrt_mixinmethod
    def SetColorProperty(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualSource2, propertyName: WinRT_String, value: win32more.Windows.UI.Color) -> Void: ...
    Markers = property(get_Markers, None)
class AnimatedChevronUpDownSmallVisualSource(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualSource
    _classid_ = 'Microsoft.UI.Xaml.Controls.AnimatedVisuals.AnimatedChevronUpDownSmallVisualSource'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.AnimatedVisuals.AnimatedChevronUpDownSmallVisualSource.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.AnimatedVisuals.AnimatedChevronUpDownSmallVisualSource: ...
    @winrt_mixinmethod
    def TryCreateAnimatedVisual(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualSource, compositor: win32more.Microsoft.UI.Composition.Compositor, diagnostics: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisual: ...
    @winrt_mixinmethod
    def get_Markers(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualSource2) -> win32more.Windows.Foundation.Collections.IMapView[WinRT_String, Double]: ...
    @winrt_mixinmethod
    def SetColorProperty(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualSource2, propertyName: WinRT_String, value: win32more.Windows.UI.Color) -> Void: ...
    Markers = property(get_Markers, None)
class AnimatedFindVisualSource(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualSource
    _classid_ = 'Microsoft.UI.Xaml.Controls.AnimatedVisuals.AnimatedFindVisualSource'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.AnimatedVisuals.AnimatedFindVisualSource.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.AnimatedVisuals.AnimatedFindVisualSource: ...
    @winrt_mixinmethod
    def TryCreateAnimatedVisual(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualSource, compositor: win32more.Microsoft.UI.Composition.Compositor, diagnostics: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisual: ...
    @winrt_mixinmethod
    def get_Markers(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualSource2) -> win32more.Windows.Foundation.Collections.IMapView[WinRT_String, Double]: ...
    @winrt_mixinmethod
    def SetColorProperty(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualSource2, propertyName: WinRT_String, value: win32more.Windows.UI.Color) -> Void: ...
    Markers = property(get_Markers, None)
class AnimatedGlobalNavigationButtonVisualSource(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualSource
    _classid_ = 'Microsoft.UI.Xaml.Controls.AnimatedVisuals.AnimatedGlobalNavigationButtonVisualSource'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.AnimatedVisuals.AnimatedGlobalNavigationButtonVisualSource.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.AnimatedVisuals.AnimatedGlobalNavigationButtonVisualSource: ...
    @winrt_mixinmethod
    def TryCreateAnimatedVisual(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualSource, compositor: win32more.Microsoft.UI.Composition.Compositor, diagnostics: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisual: ...
    @winrt_mixinmethod
    def get_Markers(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualSource2) -> win32more.Windows.Foundation.Collections.IMapView[WinRT_String, Double]: ...
    @winrt_mixinmethod
    def SetColorProperty(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualSource2, propertyName: WinRT_String, value: win32more.Windows.UI.Color) -> Void: ...
    Markers = property(get_Markers, None)
class AnimatedSettingsVisualSource(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualSource
    _classid_ = 'Microsoft.UI.Xaml.Controls.AnimatedVisuals.AnimatedSettingsVisualSource'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Controls.AnimatedVisuals.AnimatedSettingsVisualSource.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Controls.AnimatedVisuals.AnimatedSettingsVisualSource: ...
    @winrt_mixinmethod
    def TryCreateAnimatedVisual(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualSource, compositor: win32more.Microsoft.UI.Composition.Compositor, diagnostics: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisual: ...
    @winrt_mixinmethod
    def get_Markers(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualSource2) -> win32more.Windows.Foundation.Collections.IMapView[WinRT_String, Double]: ...
    @winrt_mixinmethod
    def SetColorProperty(self: win32more.Microsoft.UI.Xaml.Controls.IAnimatedVisualSource2, propertyName: WinRT_String, value: win32more.Windows.UI.Color) -> Void: ...
    Markers = property(get_Markers, None)


make_ready(__name__)



from __future__ import annotations
from win32more.winrt.prelude import *
import win32more.Microsoft.Windows.AI
import win32more.Windows.Foundation
AIFeatureReadyContract: UInt32 = 65536
class AIFeatureReadyResult(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.AI.IAIFeatureReadyResult
    _classid_ = 'Microsoft.Windows.AI.AIFeatureReadyResult'
    @winrt_mixinmethod
    def get_Error(self: win32more.Microsoft.Windows.AI.IAIFeatureReadyResult) -> win32more.Windows.Foundation.HResult: ...
    @winrt_mixinmethod
    def get_ErrorDisplayText(self: win32more.Microsoft.Windows.AI.IAIFeatureReadyResult) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_ExtendedError(self: win32more.Microsoft.Windows.AI.IAIFeatureReadyResult) -> win32more.Windows.Foundation.HResult: ...
    @winrt_mixinmethod
    def get_Status(self: win32more.Microsoft.Windows.AI.IAIFeatureReadyResult) -> win32more.Microsoft.Windows.AI.AIFeatureReadyResultState: ...
    Error = property(get_Error, None)
    ErrorDisplayText = property(get_ErrorDisplayText, None)
    ExtendedError = property(get_ExtendedError, None)
    Status = property(get_Status, None)
class AIFeatureReadyResultState(Enum, Int32):
    InProgress = 0
    Success = 1
    Failure = 2
class AIFeatureReadyState(Enum, Int32):
    Ready = 0
    NotReady = 1
    NotSupportedOnCurrentSystem = 2
    DisabledByUser = 3
class IAIFeatureReadyResult(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.IAIFeatureReadyResult'
    _iid_ = Guid('{936a78a6-c242-5937-9814-e512d4193a6d}')
    @winrt_commethod(6)
    def get_Error(self) -> win32more.Windows.Foundation.HResult: ...
    @winrt_commethod(7)
    def get_ErrorDisplayText(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_ExtendedError(self) -> win32more.Windows.Foundation.HResult: ...
    @winrt_commethod(9)
    def get_Status(self) -> win32more.Microsoft.Windows.AI.AIFeatureReadyResultState: ...
    Error = property(get_Error, None)
    ErrorDisplayText = property(get_ErrorDisplayText, None)
    ExtendedError = property(get_ExtendedError, None)
    Status = property(get_Status, None)


make_ready(__name__)



from __future__ import annotations
from win32more.winrt.prelude import *
import win32more.Microsoft.Windows.Globalization
import win32more.Windows.Foundation.Collections
class _ApplicationLanguages_Meta_(ComPtr.__class__):
    pass
class ApplicationLanguages(ComPtr, metaclass=_ApplicationLanguages_Meta_):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.Globalization.ApplicationLanguages'
    @winrt_classmethod
    def get_Languages(cls: win32more.Microsoft.Windows.Globalization.IApplicationLanguagesStatics) -> win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]: ...
    @winrt_classmethod
    def get_ManifestLanguages(cls: win32more.Microsoft.Windows.Globalization.IApplicationLanguagesStatics) -> win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]: ...
    @winrt_classmethod
    def get_PrimaryLanguageOverride(cls: win32more.Microsoft.Windows.Globalization.IApplicationLanguagesStatics) -> WinRT_String: ...
    @winrt_classmethod
    def put_PrimaryLanguageOverride(cls: win32more.Microsoft.Windows.Globalization.IApplicationLanguagesStatics, value: WinRT_String) -> Void: ...
    _ApplicationLanguages_Meta_.Languages = property(get_Languages, None)
    _ApplicationLanguages_Meta_.ManifestLanguages = property(get_ManifestLanguages, None)
    _ApplicationLanguages_Meta_.PrimaryLanguageOverride = property(get_PrimaryLanguageOverride, put_PrimaryLanguageOverride)
class IApplicationLanguagesStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.Globalization.IApplicationLanguagesStatics'
    _iid_ = Guid('{58dfcef9-08ec-5086-8af1-d5beab79250a}')
    @winrt_commethod(6)
    def get_Languages(self) -> win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]: ...
    @winrt_commethod(7)
    def get_ManifestLanguages(self) -> win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]: ...
    @winrt_commethod(8)
    def get_PrimaryLanguageOverride(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def put_PrimaryLanguageOverride(self, value: WinRT_String) -> Void: ...
    Languages = property(get_Languages, None)
    ManifestLanguages = property(get_ManifestLanguages, None)
    PrimaryLanguageOverride = property(get_PrimaryLanguageOverride, put_PrimaryLanguageOverride)


make_ready(__name__)



from __future__ import annotations
from win32more.winrt.prelude import *
import win32more.Microsoft.UI
import win32more.Microsoft.UI.System
import win32more.Windows.Foundation
class IThemeSettings(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.System.IThemeSettings'
    _iid_ = Guid('{2228ee7e-6d15-563c-8f3c-e8783ba13846}')
    @winrt_commethod(6)
    def add_Changed(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.System.ThemeSettings, IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(7)
    def remove_Changed(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(8)
    def get_HighContrast(self) -> Boolean: ...
    @winrt_commethod(9)
    def get_HighContrastScheme(self) -> WinRT_String: ...
    HighContrast = property(get_HighContrast, None)
    HighContrastScheme = property(get_HighContrastScheme, None)
    Changed = event()
class IThemeSettingsStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.System.IThemeSettingsStatics'
    _iid_ = Guid('{1586907d-30db-5f97-8fa1-8940c75dccc0}')
    @winrt_commethod(6)
    def CreateForWindowId(self, windowId: win32more.Microsoft.UI.WindowId) -> win32more.Microsoft.UI.System.ThemeSettings: ...
class ThemeSettings(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.System.IThemeSettings
    _classid_ = 'Microsoft.UI.System.ThemeSettings'
    @winrt_mixinmethod
    def add_Changed(self: win32more.Microsoft.UI.System.IThemeSettings, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.System.ThemeSettings, IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Changed(self: win32more.Microsoft.UI.System.IThemeSettings, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_HighContrast(self: win32more.Microsoft.UI.System.IThemeSettings) -> Boolean: ...
    @winrt_mixinmethod
    def get_HighContrastScheme(self: win32more.Microsoft.UI.System.IThemeSettings) -> WinRT_String: ...
    @winrt_classmethod
    def CreateForWindowId(cls: win32more.Microsoft.UI.System.IThemeSettingsStatics, windowId: win32more.Microsoft.UI.WindowId) -> win32more.Microsoft.UI.System.ThemeSettings: ...
    HighContrast = property(get_HighContrast, None)
    HighContrastScheme = property(get_HighContrastScheme, None)
    Changed = event()


make_ready(__name__)



from __future__ import annotations
from win32more.winrt.prelude import *
import win32more.Microsoft.UI
import win32more.Microsoft.UI.Composition
import win32more.Microsoft.UI.Content
import win32more.Microsoft.UI.Xaml
import win32more.Microsoft.UI.Xaml.Controls
import win32more.Microsoft.UI.Xaml.Hosting
import win32more.Microsoft.UI.Xaml.Media
import win32more.Windows.Foundation
class DesktopWindowXamlSource(ComPtr):
    extends: IInspectable
    implements: Tuple[ContextManagerProtocol]
    default_interface: win32more.Microsoft.UI.Xaml.Hosting.IDesktopWindowXamlSource
    _classid_ = 'Microsoft.UI.Xaml.Hosting.DesktopWindowXamlSource'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Hosting.DesktopWindowXamlSource.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Hosting.IDesktopWindowXamlSourceFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Hosting.DesktopWindowXamlSource: ...
    @winrt_mixinmethod
    def get_Content(self: win32more.Microsoft.UI.Xaml.Hosting.IDesktopWindowXamlSource) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_mixinmethod
    def put_Content(self: win32more.Microsoft.UI.Xaml.Hosting.IDesktopWindowXamlSource, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_mixinmethod
    def get_HasFocus(self: win32more.Microsoft.UI.Xaml.Hosting.IDesktopWindowXamlSource) -> Boolean: ...
    @winrt_mixinmethod
    def get_SystemBackdrop(self: win32more.Microsoft.UI.Xaml.Hosting.IDesktopWindowXamlSource) -> win32more.Microsoft.UI.Xaml.Media.SystemBackdrop: ...
    @winrt_mixinmethod
    def put_SystemBackdrop(self: win32more.Microsoft.UI.Xaml.Hosting.IDesktopWindowXamlSource, value: win32more.Microsoft.UI.Xaml.Media.SystemBackdrop) -> Void: ...
    @winrt_mixinmethod
    def get_SiteBridge(self: win32more.Microsoft.UI.Xaml.Hosting.IDesktopWindowXamlSource) -> win32more.Microsoft.UI.Content.DesktopChildSiteBridge: ...
    @winrt_mixinmethod
    def add_TakeFocusRequested(self: win32more.Microsoft.UI.Xaml.Hosting.IDesktopWindowXamlSource, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Hosting.DesktopWindowXamlSource, win32more.Microsoft.UI.Xaml.Hosting.DesktopWindowXamlSourceTakeFocusRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_TakeFocusRequested(self: win32more.Microsoft.UI.Xaml.Hosting.IDesktopWindowXamlSource, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_GotFocus(self: win32more.Microsoft.UI.Xaml.Hosting.IDesktopWindowXamlSource, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Hosting.DesktopWindowXamlSource, win32more.Microsoft.UI.Xaml.Hosting.DesktopWindowXamlSourceGotFocusEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_GotFocus(self: win32more.Microsoft.UI.Xaml.Hosting.IDesktopWindowXamlSource, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def NavigateFocus(self: win32more.Microsoft.UI.Xaml.Hosting.IDesktopWindowXamlSource, request: win32more.Microsoft.UI.Xaml.Hosting.XamlSourceFocusNavigationRequest) -> win32more.Microsoft.UI.Xaml.Hosting.XamlSourceFocusNavigationResult: ...
    @winrt_mixinmethod
    def Initialize(self: win32more.Microsoft.UI.Xaml.Hosting.IDesktopWindowXamlSource, parentWindowId: win32more.Microsoft.UI.WindowId) -> Void: ...
    @winrt_mixinmethod
    def get_ShouldConstrainPopupsToWorkArea(self: win32more.Microsoft.UI.Xaml.Hosting.IDesktopWindowXamlSource2) -> Boolean: ...
    @winrt_mixinmethod
    def put_ShouldConstrainPopupsToWorkArea(self: win32more.Microsoft.UI.Xaml.Hosting.IDesktopWindowXamlSource2, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IClosable) -> Void: ...
    Content = property(get_Content, put_Content)
    HasFocus = property(get_HasFocus, None)
    ShouldConstrainPopupsToWorkArea = property(get_ShouldConstrainPopupsToWorkArea, put_ShouldConstrainPopupsToWorkArea)
    SiteBridge = property(get_SiteBridge, None)
    SystemBackdrop = property(get_SystemBackdrop, put_SystemBackdrop)
    TakeFocusRequested = event()
    GotFocus = event()
class DesktopWindowXamlSourceGotFocusEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Hosting.IDesktopWindowXamlSourceGotFocusEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Hosting.DesktopWindowXamlSourceGotFocusEventArgs'
    @winrt_mixinmethod
    def get_Request(self: win32more.Microsoft.UI.Xaml.Hosting.IDesktopWindowXamlSourceGotFocusEventArgs) -> win32more.Microsoft.UI.Xaml.Hosting.XamlSourceFocusNavigationRequest: ...
    Request = property(get_Request, None)
class DesktopWindowXamlSourceTakeFocusRequestedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Hosting.IDesktopWindowXamlSourceTakeFocusRequestedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Hosting.DesktopWindowXamlSourceTakeFocusRequestedEventArgs'
    @winrt_mixinmethod
    def get_Request(self: win32more.Microsoft.UI.Xaml.Hosting.IDesktopWindowXamlSourceTakeFocusRequestedEventArgs) -> win32more.Microsoft.UI.Xaml.Hosting.XamlSourceFocusNavigationRequest: ...
    Request = property(get_Request, None)
class ElementCompositionPreview(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Hosting.IElementCompositionPreview
    _classid_ = 'Microsoft.UI.Xaml.Hosting.ElementCompositionPreview'
    @winrt_classmethod
    def GetElementVisual(cls: win32more.Microsoft.UI.Xaml.Hosting.IElementCompositionPreviewStatics, element: win32more.Microsoft.UI.Xaml.UIElement) -> win32more.Microsoft.UI.Composition.Visual: ...
    @winrt_classmethod
    def GetElementChildVisual(cls: win32more.Microsoft.UI.Xaml.Hosting.IElementCompositionPreviewStatics, element: win32more.Microsoft.UI.Xaml.UIElement) -> win32more.Microsoft.UI.Composition.Visual: ...
    @winrt_classmethod
    def SetElementChildVisual(cls: win32more.Microsoft.UI.Xaml.Hosting.IElementCompositionPreviewStatics, element: win32more.Microsoft.UI.Xaml.UIElement, visual: win32more.Microsoft.UI.Composition.Visual) -> Void: ...
    @winrt_classmethod
    def GetScrollViewerManipulationPropertySet(cls: win32more.Microsoft.UI.Xaml.Hosting.IElementCompositionPreviewStatics, scrollViewer: win32more.Microsoft.UI.Xaml.Controls.ScrollViewer) -> win32more.Microsoft.UI.Composition.CompositionPropertySet: ...
    @winrt_classmethod
    def SetImplicitShowAnimation(cls: win32more.Microsoft.UI.Xaml.Hosting.IElementCompositionPreviewStatics, element: win32more.Microsoft.UI.Xaml.UIElement, animation: win32more.Microsoft.UI.Composition.ICompositionAnimationBase) -> Void: ...
    @winrt_classmethod
    def SetImplicitHideAnimation(cls: win32more.Microsoft.UI.Xaml.Hosting.IElementCompositionPreviewStatics, element: win32more.Microsoft.UI.Xaml.UIElement, animation: win32more.Microsoft.UI.Composition.ICompositionAnimationBase) -> Void: ...
    @winrt_classmethod
    def SetIsTranslationEnabled(cls: win32more.Microsoft.UI.Xaml.Hosting.IElementCompositionPreviewStatics, element: win32more.Microsoft.UI.Xaml.UIElement, value: Boolean) -> Void: ...
    @winrt_classmethod
    def GetPointerPositionPropertySet(cls: win32more.Microsoft.UI.Xaml.Hosting.IElementCompositionPreviewStatics, targetElement: win32more.Microsoft.UI.Xaml.UIElement) -> win32more.Microsoft.UI.Composition.CompositionPropertySet: ...
class IDesktopWindowXamlSource(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Hosting.IDesktopWindowXamlSource'
    _iid_ = Guid('{553af92c-1381-51d6-bee0-f34beb042ea8}')
    @winrt_commethod(6)
    def get_Content(self) -> win32more.Microsoft.UI.Xaml.UIElement: ...
    @winrt_commethod(7)
    def put_Content(self, value: win32more.Microsoft.UI.Xaml.UIElement) -> Void: ...
    @winrt_commethod(8)
    def get_HasFocus(self) -> Boolean: ...
    @winrt_commethod(9)
    def get_SystemBackdrop(self) -> win32more.Microsoft.UI.Xaml.Media.SystemBackdrop: ...
    @winrt_commethod(10)
    def put_SystemBackdrop(self, value: win32more.Microsoft.UI.Xaml.Media.SystemBackdrop) -> Void: ...
    @winrt_commethod(11)
    def get_SiteBridge(self) -> win32more.Microsoft.UI.Content.DesktopChildSiteBridge: ...
    @winrt_commethod(12)
    def add_TakeFocusRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Hosting.DesktopWindowXamlSource, win32more.Microsoft.UI.Xaml.Hosting.DesktopWindowXamlSourceTakeFocusRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(13)
    def remove_TakeFocusRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(14)
    def add_GotFocus(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Hosting.DesktopWindowXamlSource, win32more.Microsoft.UI.Xaml.Hosting.DesktopWindowXamlSourceGotFocusEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(15)
    def remove_GotFocus(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(16)
    def NavigateFocus(self, request: win32more.Microsoft.UI.Xaml.Hosting.XamlSourceFocusNavigationRequest) -> win32more.Microsoft.UI.Xaml.Hosting.XamlSourceFocusNavigationResult: ...
    @winrt_commethod(17)
    def Initialize(self, parentWindowId: win32more.Microsoft.UI.WindowId) -> Void: ...
    Content = property(get_Content, put_Content)
    HasFocus = property(get_HasFocus, None)
    SiteBridge = property(get_SiteBridge, None)
    SystemBackdrop = property(get_SystemBackdrop, put_SystemBackdrop)
    TakeFocusRequested = event()
    GotFocus = event()
class IDesktopWindowXamlSource2(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Hosting.IDesktopWindowXamlSource2'
    _iid_ = Guid('{fb02b9f1-8588-5bd3-8951-4664a675d872}')
    @winrt_commethod(6)
    def get_ShouldConstrainPopupsToWorkArea(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_ShouldConstrainPopupsToWorkArea(self, value: Boolean) -> Void: ...
    ShouldConstrainPopupsToWorkArea = property(get_ShouldConstrainPopupsToWorkArea, put_ShouldConstrainPopupsToWorkArea)
class IDesktopWindowXamlSourceFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Hosting.IDesktopWindowXamlSourceFactory'
    _iid_ = Guid('{7d2db617-14e7-5d49-aeec-ae10887e595d}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Hosting.DesktopWindowXamlSource: ...
class IDesktopWindowXamlSourceGotFocusEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Hosting.IDesktopWindowXamlSourceGotFocusEventArgs'
    _iid_ = Guid('{cc63d863-2071-5f6b-aef9-c0ba35f3b8df}')
    @winrt_commethod(6)
    def get_Request(self) -> win32more.Microsoft.UI.Xaml.Hosting.XamlSourceFocusNavigationRequest: ...
    Request = property(get_Request, None)
class IDesktopWindowXamlSourceTakeFocusRequestedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Hosting.IDesktopWindowXamlSourceTakeFocusRequestedEventArgs'
    _iid_ = Guid('{4f5a0e2c-4ddc-5c03-939f-6f3bda560363}')
    @winrt_commethod(6)
    def get_Request(self) -> win32more.Microsoft.UI.Xaml.Hosting.XamlSourceFocusNavigationRequest: ...
    Request = property(get_Request, None)
class IElementCompositionPreview(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Hosting.IElementCompositionPreview'
    _iid_ = Guid('{c8ad1ef4-a93f-5a25-85bd-7c498d9856d3}')
class IElementCompositionPreviewStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Hosting.IElementCompositionPreviewStatics'
    _iid_ = Guid('{84da5a6c-0cfa-532b-9b15-ccd986374342}')
    @winrt_commethod(6)
    def GetElementVisual(self, element: win32more.Microsoft.UI.Xaml.UIElement) -> win32more.Microsoft.UI.Composition.Visual: ...
    @winrt_commethod(7)
    def GetElementChildVisual(self, element: win32more.Microsoft.UI.Xaml.UIElement) -> win32more.Microsoft.UI.Composition.Visual: ...
    @winrt_commethod(8)
    def SetElementChildVisual(self, element: win32more.Microsoft.UI.Xaml.UIElement, visual: win32more.Microsoft.UI.Composition.Visual) -> Void: ...
    @winrt_commethod(9)
    def GetScrollViewerManipulationPropertySet(self, scrollViewer: win32more.Microsoft.UI.Xaml.Controls.ScrollViewer) -> win32more.Microsoft.UI.Composition.CompositionPropertySet: ...
    @winrt_commethod(10)
    def SetImplicitShowAnimation(self, element: win32more.Microsoft.UI.Xaml.UIElement, animation: win32more.Microsoft.UI.Composition.ICompositionAnimationBase) -> Void: ...
    @winrt_commethod(11)
    def SetImplicitHideAnimation(self, element: win32more.Microsoft.UI.Xaml.UIElement, animation: win32more.Microsoft.UI.Composition.ICompositionAnimationBase) -> Void: ...
    @winrt_commethod(12)
    def SetIsTranslationEnabled(self, element: win32more.Microsoft.UI.Xaml.UIElement, value: Boolean) -> Void: ...
    @winrt_commethod(13)
    def GetPointerPositionPropertySet(self, targetElement: win32more.Microsoft.UI.Xaml.UIElement) -> win32more.Microsoft.UI.Composition.CompositionPropertySet: ...
class IWindowsXamlManager(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Hosting.IWindowsXamlManager'
    _iid_ = Guid('{85a2e562-7e8f-5333-a104-a3e672a2ffee}')
class IWindowsXamlManager2(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Hosting.IWindowsXamlManager2'
    _iid_ = Guid('{bd67cff5-b887-56da-b0a2-dad10a6520e9}')
    @winrt_commethod(6)
    def add_XamlShutdownCompletedOnThread(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Hosting.WindowsXamlManager, win32more.Microsoft.UI.Xaml.Hosting.XamlShutdownCompletedOnThreadEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(7)
    def remove_XamlShutdownCompletedOnThread(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    XamlShutdownCompletedOnThread = event()
class IWindowsXamlManagerStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Hosting.IWindowsXamlManagerStatics'
    _iid_ = Guid('{56cb591d-de97-539f-881d-8ccdc44fa6c4}')
    @winrt_commethod(6)
    def InitializeForCurrentThread(self) -> win32more.Microsoft.UI.Xaml.Hosting.WindowsXamlManager: ...
class IWindowsXamlManagerStatics2(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Hosting.IWindowsXamlManagerStatics2'
    _iid_ = Guid('{1062430e-0898-5240-ba52-89d9225e7e58}')
    @winrt_commethod(6)
    def GetForCurrentThread(self) -> win32more.Microsoft.UI.Xaml.Hosting.WindowsXamlManager: ...
class IXamlShutdownCompletedOnThreadEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Hosting.IXamlShutdownCompletedOnThreadEventArgs'
    _iid_ = Guid('{accd20e5-3576-5262-a3dd-990657681f1f}')
    @winrt_commethod(6)
    def GetDispatcherQueueDeferral(self) -> win32more.Windows.Foundation.Deferral: ...
class IXamlSourceFocusNavigationRequest(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Hosting.IXamlSourceFocusNavigationRequest'
    _iid_ = Guid('{c883ea8b-4ce2-58be-b547-66dedf620312}')
    @winrt_commethod(6)
    def get_Reason(self) -> win32more.Microsoft.UI.Xaml.Hosting.XamlSourceFocusNavigationReason: ...
    @winrt_commethod(7)
    def get_HintRect(self) -> win32more.Windows.Foundation.Rect: ...
    @winrt_commethod(8)
    def get_CorrelationId(self) -> Guid: ...
    CorrelationId = property(get_CorrelationId, None)
    HintRect = property(get_HintRect, None)
    Reason = property(get_Reason, None)
class IXamlSourceFocusNavigationRequestFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Hosting.IXamlSourceFocusNavigationRequestFactory'
    _iid_ = Guid('{7a5124dd-2876-5ed8-b564-5867731d7f1e}')
    @winrt_commethod(6)
    def CreateInstance(self, reason: win32more.Microsoft.UI.Xaml.Hosting.XamlSourceFocusNavigationReason) -> win32more.Microsoft.UI.Xaml.Hosting.XamlSourceFocusNavigationRequest: ...
    @winrt_commethod(7)
    def CreateInstanceWithHintRect(self, reason: win32more.Microsoft.UI.Xaml.Hosting.XamlSourceFocusNavigationReason, hintRect: win32more.Windows.Foundation.Rect) -> win32more.Microsoft.UI.Xaml.Hosting.XamlSourceFocusNavigationRequest: ...
    @winrt_commethod(8)
    def CreateInstanceWithHintRectAndCorrelationId(self, reason: win32more.Microsoft.UI.Xaml.Hosting.XamlSourceFocusNavigationReason, hintRect: win32more.Windows.Foundation.Rect, correlationId: Guid) -> win32more.Microsoft.UI.Xaml.Hosting.XamlSourceFocusNavigationRequest: ...
class IXamlSourceFocusNavigationResult(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Hosting.IXamlSourceFocusNavigationResult'
    _iid_ = Guid('{d6bf378e-2aac-5e5b-ac8a-6c5d9a4c1cb8}')
    @winrt_commethod(6)
    def get_WasFocusMoved(self) -> Boolean: ...
    WasFocusMoved = property(get_WasFocusMoved, None)
class IXamlSourceFocusNavigationResultFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Hosting.IXamlSourceFocusNavigationResultFactory'
    _iid_ = Guid('{f533f53b-5c00-5c88-9a41-3888cb86e495}')
    @winrt_commethod(6)
    def CreateInstance(self, focusMoved: Boolean) -> win32more.Microsoft.UI.Xaml.Hosting.XamlSourceFocusNavigationResult: ...
class WindowsXamlManager(ComPtr):
    extends: IInspectable
    implements: Tuple[ContextManagerProtocol]
    default_interface: win32more.Microsoft.UI.Xaml.Hosting.IWindowsXamlManager
    _classid_ = 'Microsoft.UI.Xaml.Hosting.WindowsXamlManager'
    @winrt_mixinmethod
    def add_XamlShutdownCompletedOnThread(self: win32more.Microsoft.UI.Xaml.Hosting.IWindowsXamlManager2, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Xaml.Hosting.WindowsXamlManager, win32more.Microsoft.UI.Xaml.Hosting.XamlShutdownCompletedOnThreadEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_XamlShutdownCompletedOnThread(self: win32more.Microsoft.UI.Xaml.Hosting.IWindowsXamlManager2, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IClosable) -> Void: ...
    @winrt_classmethod
    def GetForCurrentThread(cls: win32more.Microsoft.UI.Xaml.Hosting.IWindowsXamlManagerStatics2) -> win32more.Microsoft.UI.Xaml.Hosting.WindowsXamlManager: ...
    @winrt_classmethod
    def InitializeForCurrentThread(cls: win32more.Microsoft.UI.Xaml.Hosting.IWindowsXamlManagerStatics) -> win32more.Microsoft.UI.Xaml.Hosting.WindowsXamlManager: ...
    XamlShutdownCompletedOnThread = event()
class XamlShutdownCompletedOnThreadEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Hosting.IXamlShutdownCompletedOnThreadEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Hosting.XamlShutdownCompletedOnThreadEventArgs'
    @winrt_mixinmethod
    def GetDispatcherQueueDeferral(self: win32more.Microsoft.UI.Xaml.Hosting.IXamlShutdownCompletedOnThreadEventArgs) -> win32more.Windows.Foundation.Deferral: ...
class XamlSourceFocusNavigationReason(Enum, Int32):
    Programmatic = 0
    Restore = 1
    First = 3
    Last = 4
    Left = 7
    Up = 8
    Right = 9
    Down = 10
class XamlSourceFocusNavigationRequest(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Hosting.IXamlSourceFocusNavigationRequest
    _classid_ = 'Microsoft.UI.Xaml.Hosting.XamlSourceFocusNavigationRequest'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 1:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Hosting.XamlSourceFocusNavigationRequest.CreateInstance(*args))
        elif len(args) == 2:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Hosting.XamlSourceFocusNavigationRequest.CreateInstanceWithHintRect(*args))
        elif len(args) == 3:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Hosting.XamlSourceFocusNavigationRequest.CreateInstanceWithHintRectAndCorrelationId(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Hosting.IXamlSourceFocusNavigationRequestFactory, reason: win32more.Microsoft.UI.Xaml.Hosting.XamlSourceFocusNavigationReason) -> win32more.Microsoft.UI.Xaml.Hosting.XamlSourceFocusNavigationRequest: ...
    @winrt_factorymethod
    def CreateInstanceWithHintRect(cls: win32more.Microsoft.UI.Xaml.Hosting.IXamlSourceFocusNavigationRequestFactory, reason: win32more.Microsoft.UI.Xaml.Hosting.XamlSourceFocusNavigationReason, hintRect: win32more.Windows.Foundation.Rect) -> win32more.Microsoft.UI.Xaml.Hosting.XamlSourceFocusNavigationRequest: ...
    @winrt_factorymethod
    def CreateInstanceWithHintRectAndCorrelationId(cls: win32more.Microsoft.UI.Xaml.Hosting.IXamlSourceFocusNavigationRequestFactory, reason: win32more.Microsoft.UI.Xaml.Hosting.XamlSourceFocusNavigationReason, hintRect: win32more.Windows.Foundation.Rect, correlationId: Guid) -> win32more.Microsoft.UI.Xaml.Hosting.XamlSourceFocusNavigationRequest: ...
    @winrt_mixinmethod
    def get_Reason(self: win32more.Microsoft.UI.Xaml.Hosting.IXamlSourceFocusNavigationRequest) -> win32more.Microsoft.UI.Xaml.Hosting.XamlSourceFocusNavigationReason: ...
    @winrt_mixinmethod
    def get_HintRect(self: win32more.Microsoft.UI.Xaml.Hosting.IXamlSourceFocusNavigationRequest) -> win32more.Windows.Foundation.Rect: ...
    @winrt_mixinmethod
    def get_CorrelationId(self: win32more.Microsoft.UI.Xaml.Hosting.IXamlSourceFocusNavigationRequest) -> Guid: ...
    CorrelationId = property(get_CorrelationId, None)
    HintRect = property(get_HintRect, None)
    Reason = property(get_Reason, None)
class XamlSourceFocusNavigationResult(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Hosting.IXamlSourceFocusNavigationResult
    _classid_ = 'Microsoft.UI.Xaml.Hosting.XamlSourceFocusNavigationResult'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 1:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Hosting.XamlSourceFocusNavigationResult.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Hosting.IXamlSourceFocusNavigationResultFactory, focusMoved: Boolean) -> win32more.Microsoft.UI.Xaml.Hosting.XamlSourceFocusNavigationResult: ...
    @winrt_mixinmethod
    def get_WasFocusMoved(self: win32more.Microsoft.UI.Xaml.Hosting.IXamlSourceFocusNavigationResult) -> Boolean: ...
    WasFocusMoved = property(get_WasFocusMoved, None)


make_ready(__name__)
